@@ -65,6 +65,7 @@ type Flags struct {
 	UseSIPrefix       bool     `yaml:"use-si-prefix"`
 	NoPrefix          bool     `yaml:"no-prefix"`
 	WriteConfig       bool     `yaml:"-"`
+	ChangeCwd         bool     `yaml:"change-cwd"`
 	Style             Style    `yaml:"style"`
 	Sorting           Sorting  `yaml:"sorting"`
 }
@@ -240,6 +241,11 @@ func (a *App) createUI() (UI, error) {
 				ui.SetDefaultSorting(a.Flags.Sorting.By, a.Flags.Sorting.Order)
 			})
 		}
+		if a.Flags.ChangeCwd != false {
+			opts = append(opts, func(ui *tui.UI) {
+				ui.SetChangeCwdFn(os.Chdir)
+			})
+		}
 
 		ui = tui.CreateUI(
 			a.TermApp,
